@@ -25,5 +25,18 @@ namespace interop_test
             });
         }
 
+        [Fact]
+        public void pattern_api_entry()
+        {
+            // TODO: Why does this not work?
+            Interop.my_api_init_v1(out var api);
+            
+            var input = new Tupled {x0 = 10};
+            var output = api.tupled(input);
+            
+            Assert.Equal(2 * input.x0, output.x0);
+            
+        }
+
     }
 }
\ No newline at end of file
